@@ -1,4 +1,5 @@
 from unicurses import OPERATING_SYSTEM
+from shutil    import which
 
 
 
@@ -17,11 +18,10 @@ class TUIFIProfile: #█┇▓┃▒┃░┃
 
 
 
-DEFAULT_OPENER       = 'start' if 'Windows' else 'open' if 'Darwin' else 'xdg-open'  # meh..
-DEFAULT_EDITOR       = 'vim'
-DEFAULT_UNCOMPRESSOR = 'vim'
+DEFAULT_OPENER = 'start' if 'Windows' == OPERATING_SYSTEM else 'open' if 'Darwin' == OPERATING_SYSTEM  else 'xdg-open'   # meh.. # TODO: make an enviromental variable insted of those 2 vars, for everything
+DEFAULT_EDITOR = which('nvim') or which('emacs') or which('vim') or which('micro') or which('nano')  or DEFAULT_OPENER 
 
-TUIFIProfiles = {
+TUIFIProfiles = { # TODO: open zip rar and etc. files on __init__.py as if they where kind of folders?
     'folder':TUIFIProfile((
         ' █████▒⎫⎫ \n'
         ' █████▒▐┇ \n'
@@ -34,6 +34,18 @@ TUIFIProfiles = {
         ' █████ ┃┃ \n'
         ' ▀▀▀▀▀  ┘ '
     ),2),
+    '.xlsx':TUIFIProfile((
+        ' ┏━━━━┳┳┓ \n'
+        ' ┃██▓░┣╋┫ \n'
+        ' ┃EXCEL╋┫ \n' 
+        ' ╰━━━━┻┻┛ ' 
+    ),5, DEFAULT_OPENER),
+    '.ino':TUIFIProfile((
+        ' ╭━┳┳┳++╮ \n' 
+        ' ┃ARDINO┃ \n' 
+        ' ┃╭╯╰╯+╮┃ \n' 
+        ' ╰┻━━┻┻┻╯ '
+    ),4, DEFAULT_EDITOR),
     'file':TUIFIProfile((
         ' ┏┏━━━━┓┓ \n'
         ' ┇┛FILE ┃ \n'  # 𝗙𝗜𝗟𝗘
@@ -84,9 +96,9 @@ TUIFIProfiles = {
     ),4, DEFAULT_EDITOR),
     '.md':TUIFIProfile((
         ' ┏━━━━━━┓ \n'
-        ' ┃█▅▂▅█┇┇ \n'  
-        ' ┃█▔▀▔█v┃ \n'
-        ' ┗━━━━━━┛ ' 
+        ' ┃█▀▅▀▄/┇ \n'  
+        ' ┃DOWN//┃ \n'
+        ' ╰━━━━━━┛ ' 
     ),4, DEFAULT_EDITOR),
     '.json':TUIFIProfile((
         ' ┏━━━━┓━┓ \n'
@@ -150,22 +162,28 @@ TUIFIProfiles = {
     ),1, DEFAULT_EDITOR),
     '.css':TUIFIProfile((
         ' ╭━━━━╮╮╮ \n'
-        ' ┃CSS┃██┃ \n'
+        ' ┃CSS┃▅▅┃ \n'
         ' ┃┇▒▒┃☲☰┃ \n'
         ' ┗━━━╯━━╯ '
     ),2, DEFAULT_EDITOR),
+    '.scss':TUIFIProfile((
+        ' ╭━━━━╮╮╮ \n'
+        ' ┃SCS┃▅▅┃ \n'
+        ' ┃┇▒▒┃S☲┃ \n'
+        ' ┗━━━╯━━╯ '
+    ),2, DEFAULT_EDITOR),
     '.pdf':TUIFIProfile((
         ' ╭━━━━╮━╮ \n'
         ' ┃PDF┃☲ ┃ \n'
         ' ┃┇▒█┃▒▒┃ \n'
         ' ┗━━━━━━╯ '
-    ),3),
+    ),3, DEFAULT_OPENER),
     '.bin':TUIFIProfile((
         ' ╭━━━━━━╮ \n'
         ' ┃☴☱☶☵ ∟┇ \n'
         ' ┇☱☶ BIN┃ \n'
         ' ╰━━━━━━╯ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.sh':TUIFIProfile((
         ' ╭━━━━━━╮ \n'
         ' ┃ $_   ┃ \n'
@@ -189,200 +207,204 @@ TUIFIProfiles = {
         ' │S┃O┃│Ξ┃ \n'
         ' │█┃▒││▓╿ \n'
         ' ╰━┘━┘╰━┘ ' 
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.dll':TUIFIProfile((
         ' ╭━┓━┓╭━┓ \n'
         ' │D┃L┃│L┃ \n'
         ' │█┃▒││▓╿ \n'
         ' ╰━┘━┘╰━┘ ' 
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.rar':TUIFIProfile((
         ' ▃▃RAR▃▃╮ \n'
         ' ▒▒░ ░▒▒┃ \n'
         ' ▓▓░ ░▓▓┃ \n'
         ' ▀▀░ ░▀▀┘ '
-    ),2,DEFAULT_UNCOMPRESSOR),
+    ),2, DEFAULT_OPENER),
     '.zip':TUIFIProfile((
         ' ▃▃▃░░▃▃▃ \n'
         ' ▒▒▒░░▒▒▒ \n' 
         ' ▓▓▓░░▓▓▓ \n' 
         ' ZIP░░▀▀▀ '
-    ),2,DEFAULT_UNCOMPRESSOR),
+    ),2, DEFAULT_OPENER),
     '.tar':TUIFIProfile((
         ' ▃▃▃░░▃▃▃ \n'
         ' ▒▒▒░░▒▒▒ \n' 
         ' ▓▓▓░░▓▓▓ \n' 
         ' TAR░░▀▀▀ '
-    ),2,DEFAULT_UNCOMPRESSOR),
+    ),2, DEFAULT_OPENER),
     '.gz':TUIFIProfile((
         ' ▃▃▃░░▃▃▃ \n'
         ' ▒▒▒░░▒▒▒ \n' 
         ' ▓▓▓░░▓▓▓ \n' 
         ' TAR░░▀▀▀ '
-    ),2,DEFAULT_UNCOMPRESSOR),
+    ),2, DEFAULT_OPENER),
     '.xz':TUIFIProfile((
         ' ▃▃▃░░▃▃▃ \n'
         ' ▒▒▒░░▒▒▒ \n' 
         ' ▓▓▓░░▓▓▓ \n' 
         ' TAR░░▀▀▀ '
-    ),2,DEFAULT_UNCOMPRESSOR),
+    ),2, DEFAULT_OPENER),
     '.bz2':TUIFIProfile((
         ' ▃▃▃░░▃▃▃ \n'
         ' ▒▒▒░░▒▒▒ \n' 
         ' ▓▓▓░░▓▓▓ \n' 
         ' TAR░░▀▀▀ '
-    ),2,DEFAULT_UNCOMPRESSOR),
+    ),2, DEFAULT_OPENER),
     '.zst':TUIFIProfile((
         ' ▃▃▃░░▃▃▃ \n'
         ' ▒▒▒░░▒▒▒ \n' 
         ' ▓▓▓░░▓▓▓ \n' 
         ' TAR░░▀▀▀ '
-    ),2,DEFAULT_UNCOMPRESSOR),
+    ),2, DEFAULT_OPENER),
+    
     '.gif':TUIFIProfile((
-        ' ╭━━━━━━╮ \n'
-        ' ┃GIF╭▒█┫ \n'
-        ' ┠┇██┤☍ ┃ \n'
-        ' ┗━━━━━━╯ '
-    ),2),
+        ' ┏━━━┳┳┳┓ \n'
+        ' ┃GIF:∵◖┇ \n'
+        ' ┠┓░▃_▓▆┇ \n'
+        ' ╰━━━┻┻┻┛ '
+    ),2, DEFAULT_OPENER),
+    
     '.mp4':TUIFIProfile((
         ' ┏┳┳┳┳┳┳┓ \n'
         ' ┇MP4∴∵◖┇ \n'
         ' ┇_░▃_▓▆┇ \n'
         ' ┗┻┻┻┻┻┻┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.3gp':TUIFIProfile((
         ' ┏┳┳┳┳┳┳┓ \n'
         ' ┇3GP∴∵◖┇ \n'
         ' ┇_░▃_▓▆┇ \n'
         ' ┗┻┻┻┻┻┻┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     
     '.avi':TUIFIProfile((
         ' ┏┳┳┳┳┳┳┓ \n'
         ' ┇AVI∴∵◖┇ \n'
         ' ┇_░▃_▓▆┇ \n'
         ' ┗┻┻┻┻┻┻┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.webm':TUIFIProfile((
         ' ┏┳┳┳┳┳┳┓ \n'
         ' ┇WEBM∵◖┇ \n'
         ' ┇_░▃_▓▆┇ \n'
         ' ┗┻┻┻┻┻┻┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.ogv':TUIFIProfile((
         ' ┏┳┳┳┳┳┳┓ \n'
         ' ┇OGV∴∵◖┇ \n'
         ' ┇_░▃_▓▆┇ \n'
         ' ┗┻┻┻┻┻┻┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.mov':TUIFIProfile((
         ' ┏┳┳┳┳┳┳┓ \n'
         ' ┇MOV∴∵◖┇ \n'
         ' ┇_░▃_▓▆┇ \n'
         ' ┗┻┻┻┻┻┻┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.jpg':TUIFIProfile(( 
         ' ┏━━━JPG╮ \n'
         ' ┇*.∴:∵◖┃ \n'
         ' ┣┓░▃┏▓▆┇ \n'
         ' ╰━━━━━━┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.png':TUIFIProfile(( 
         ' ┏━━━PNG╮ \n'
         ' ┇*.∴:∵◖┃ \n'
         ' ┣┓░▃┏▓▆┇ \n'
         ' ╰━━━━━━┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.jpeg':TUIFIProfile(( 
         ' ┏━━JPEG╮ \n'
         ' ┇*.∴:∵◖┃ \n'
         ' ┣┓░▃┏▓▆┇ \n'
         ' ╰━━━━━━┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.bmp':TUIFIProfile(( 
         ' ┏━━━BMP┓ \n'
         ' ┇*.∴:∵◖┃ \n'
         ' ┣┓░▃┏▓▆┇ \n'
         ' ┗━━━━━━┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.webp':TUIFIProfile(( 
         ' ┏━━WEBP╮ \n'
         ' ┇*.∴:∵◖┃ \n'
         ' ┣┓░▃┏▓▆┇ \n'
         ' ╰━━━━━━┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.tiff':TUIFIProfile(( 
         ' ┏━━TIFF╮ \n'
         ' ┇*.∴:∵◖┃ \n'
         ' ┣┓░▃┏▓▆┇ \n'
         ' ╰━━━━━━┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.tif':TUIFIProfile(( 
         ' ┏━━TIFF╮ \n'
         ' ┇*.∴:∵◖┃ \n'
         ' ┣┓░▃┏▓▆┇ \n'
         ' ╰━━━━━━┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.tga':TUIFIProfile(( 
         ' ┏━TARGA╮ \n'
         ' ┇*.∴:∵◖┃ \n'
         ' ┣┓░▃┏▓▆┇ \n'
         ' ╰━━━━━━┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.heif':TUIFIProfile(( 
         ' ┏━━HEIF╮ \n'
         ' ┇*.∴:∵◖┃ \n'
         ' ┣┓░▃┏▓▆┇ \n'
         ' ╰━━━━━━┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.heifs':TUIFIProfile(( 
         ' ┏━━HEIF╮ \n'
         ' ┇*.∴:∵◖┃ \n'
         ' ┣┓░▃┏▓▆┇ \n'
         ' ╰━━━━━━┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.heic':TUIFIProfile(( 
         ' ┏━━HEIC╮ \n'
         ' ┇*.∴:∵◖┃ \n'
         ' ┣┓░▃┏▓▆┇ \n'
         ' ╰━━━━━━┛ '
-    ),2),
+    ),2, DEFAULT_OPENER),
+    
     '.mp3':TUIFIProfile(( 
-        ' ┏┓━━━━┏┓ \n'
+        ' ╭┓━━━━┏╮ \n'
         ' ┣╯MP3♪╰┫ \n'
         ' ┇┓♯⦇⦈♯┏┇ \n'
-        ' ┗┛━━━━┗┛ '
-    ),8),
+        ' ╰┛━━━━┗╯ '
+    ),8, DEFAULT_OPENER),
     '.wav':TUIFIProfile(( 
-        ' ┏┓━━━━┏┓ \n'
+        ' ╭┓━━━━┏╮ \n'
         ' ┣╯WAV♪╰┫ \n'
         ' ┇┓♯⦇⦈♯┏┇ \n'
-        ' ┗┛━━━━┗┛ '
-    ),8),
+        ' ╰┛━━━━┗╯ '
+    ),8, DEFAULT_OPENER),
     '.mid':TUIFIProfile(( 
-        ' ┏┓━━━━┏┓ \n'
+        ' ╭┓━━━━┏╮ \n'
         ' ┣╯MID♪╰┫ \n'
         ' ┇┓♯⦇⦈♯┏┇ \n'
-        ' ┗┛━━━━┗┛ '
-    ),8),
+        ' ╰┛━━━━┗╯ '
+    ),8, DEFAULT_OPENER),
     '.aac':TUIFIProfile(( 
-        ' ┏┓━━━━┏┓ \n'
+        ' ╭┓━━━━┏╮ \n'
         ' ┣╯AAC♪╰┫ \n'
         ' ┇┓♯⦇⦈♯┏┇ \n'
-        ' ┗┛━━━━┗┛ '
-    ),8),
+        ' ╰┛━━━━┗╯ '
+    ),8, DEFAULT_OPENER),
+    
     '.psd':TUIFIProfile((
         ' ╭▃▃▃ ▃▃╮ \n'
         ' ┃█▂█ █▂┃ \n'
         ' ┃█   ▃█┃ \n'
         ' ┗━PSD━━┛ '
-    ),4),
+    ),4, DEFAULT_OPENER),
     '.mdf':TUIFIProfile((
         ' ╭━━━━━━╮ \n'
         ' ┃┇DB╭▒█┫ \n'
         ' ┠┇██┻▓▒┃ \n'
         ' ┗━━━╯━━╯ '
-    ),2),
+    ),2, DEFAULT_OPENER),
     '.tuifi':TUIFIProfile((
         '             \                                      [            \n' 
         '              @                 ⟡                  ╢             \n' 
